@@ -355,8 +355,20 @@ def test_ubuntu_openssl():
     res = utils.version_compare("3.0-1", 0, "*", None, "3.0-1ubuntu0.1")
     assert res
     # Not working
-    # res = utils.version_compare("2:8.39-12build1", 0, "*", None, "8.39-9ubuntu0.1")
-    # assert res
+    # res = utils.version_compare("1.1.0j-1~deb9u1", 0, "*", None, "1.1.0f-3+deb9u1")
+    # assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1g-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1k-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", "*", "*", None, "1.1.1g-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", "*", "*", None, "1.1.1k-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb10u3", "*", "*", None, "1.1.1d-1")
+    assert not res
+    res = utils.version_compare("2:8.39-12build1", 0, "*", None, "8.39-9ubuntu0.1")
+    assert not res
     res = utils.version_compare(
         "7.7.0+dfsg-1ubuntu1", 0, "*", None, "7.7.0+dfsg-1ubuntu1.1"
     )
