@@ -329,6 +329,8 @@ class AquaSource(NvdSource):
         if isinstance(references, bytes):
             references = references.decode("utf-8", "ignore")
         description = cve_data.get("Description")
+        if "** DISPUTED **" in description or "** REJECT **" in description:
+            return ret_data
         if not description and cve_data.get("UbuntuDescription"):
             description = cve_data.get("UbuntuDescription")
         assigner = "ubuntu"
@@ -340,8 +342,11 @@ class AquaSource(NvdSource):
         lastModifiedDate = cve_data.get("PublicDate")
         for pkg_name, distro_obj in packages.items():
             for distro_name, status_obj in distro_obj.items():
+                fix_note = status_obj.get("Note")
+                # DNE - does not exist
+                # needs-triage - Vulnerability is not confirmed.
                 if status_obj.get("Status") in (
-                    "ignored",
+                    "DNE",
                     "needs-triage",
                 ):
                     continue
@@ -353,7 +358,6 @@ class AquaSource(NvdSource):
                 fix_version_start_excluding = ""
                 fix_version_end_excluding = ""
                 fix_version_start_including = ""
-                fix_note = status_obj.get("Note")
                 # Remove epoch
                 if ":" in fix_note:
                     fix_note = fix_note.split(":")[-1]
@@ -370,13 +374,20 @@ class AquaSource(NvdSource):
                     fix_version_start_including = fix_note
                     version_end_excluding = fix_note
                 # Handle CVEs that are deferred
+                # Let's include the vulnerabilities that did not get a fix
                 if (
-                    status_obj.get("Status") in ("deferred", "needed")
+                    status_obj.get("Status")
+                    in (
+                        "deferred",
+                        "needed",
+                    )
                     and " " not in fix_note
                 ):
                     version_end_including = config.placeholder_fix_version
+                if status_obj.get("Status") in ("ignored",):
+                    version_end_including = config.placeholder_fix_version
                 if pkg_name and (fix_version_start_including or version_end_including):
-                    for full_pkg_name in (f"{distro_name}/{pkg_name}", pkg_name):
+                    for full_pkg_name in (f"{distro_name}/{pkg_name}",):
                         tdata = config.CVE_TPL % dict(
                             cve_id=cve_id,
                             cwe_id=cwe_id,
@@ -736,6 +747,10 @@ class AquaSource(NvdSource):
         cwe_id = ""
         references = []
         description = header.get("Description", "").replace("(", "").replace(")", "")
+        # Try harder to retain all description
+        for ann in annotations:
+            if ann.get("Original", "").startswith("NOTE:"):
+                description = f"{description}\n{ann.get('Original')}"
         assigner = "debian"
         vendor = "debian"
         filtered_annotations = [
@@ -794,7 +809,8 @@ class AquaSource(NvdSource):
             severity = "MEDIUM"
             # Try harder to set LOW priority
             if kind == "postponed" or (
-                ann.get("Description") and ann.get("Description") == "Minor issue"
+                ann.get("Description")
+                and "minor issue" in ann.get("Description").lower()
             ):
                 severity = "LOW"
             if ann.get("Severity"):
